# snyk-ignore(1) -- Modifies the .snyk policy to ignore stated issues

## SYNOPSIS

`snyk` `ignore` `--id`=<ISSUE_ID> \[`--expiry`=<EXPIRY>\] \[`--reason`=<REASON>\] \[<OPTIONS>\]

## DESCRIPTION

Ignore a certain issue, according to its snyk ID for all occurrences. This will update your local `.snyk` to contain a similar block:

```yaml
ignore:
  '<ISSUE_ID>':
    - '*':
        reason: <REASON>
        expires: <EXPIRY>
```

## OPTIONS

- `--id`=<ISSUE_ID>:
  Snyk ID for the issue to ignore. Required.

- `--expiry`=<EXPIRY>:
  Expiry date, according to [RFC2822](https://tools.ietf.org/html/rfc2822)

- `--reason`=<REASON>:
  Human-readable <REASON> to ignore this issue.




### Flags available accross all commands

- `--insecure`:
  Ignore unknown certificate authorities.

- `-d`:
  Output debug logs.

- `--quiet`, `-q`:
  Silence all output.

- `--version`, `-v`:
  Prints versions.

- \[<COMMAND>\] `--help`, `--help` \[<COMMAND>\], `-h`:
  Prints a help text. You may specify a <COMMAND> to get more details.


## EXAMPLES

- `Ignore a specific vulnerability`:
  \$ snyk ignore --id='npm:qs:20170213' --expiry='2021-01-10' --reason='Module not affected by this vuln'


## EXIT CODES

Possible exit codes and their meaning:

**0**: success, no vulns found<br />
**1**: action_needed, vulns found<br />
**2**: failure, try to re-run command<br />
**3**: failure, no supported projects detected<br />


## ENVIRONMENT

You can set these environment variables to change CLI run settings.

- `SNYK_TOKEN`:
  Snyk authorization token. Setting this envvar will override the token that may be available in your `snyk config` settings.

  [How to get your account token](https://snyk.co/ucT6J)<br />
  [How to use Service Accounts](https://snyk.co/ucT6L)<br />

- `SNYK_API`:
  Sets API host to use for Snyk requests. Useful for on-premise instances and configuring proxies.

- `SNYK_CFG_`<KEY>:
  Allows you to override any key that's also available as `snyk config` option.

  E.g. `SNYK_CFG_ORG`=myorg will override default org option in `config` with "myorg".

- `SNYK_REGISTRY_USERNAME`:
    Specify a username to use when connecting to a container registry. Note that using the `--username` flag will
     override this value. This will be ignored in favour of local Docker binary credentials when Docker is present. 
  
- `SNYK_REGISTRY_PASSWORD`:
    Specify a password to use when connecting to a container registry. Note that using the `--password` flag will
     override this value. This will be ignored in favour of local Docker binary credentials when Docker is present. 
    


## NOTICES

### Snyk API usage policy

The use of Snyk's API, whether through the use of the 'snyk' npm package or otherwise, is subject to the [terms & conditions](https://snyk.co/ucT6N)

